# This file was auto-generated by Fern from our API Definition.

from ..core.api_error import ApiError
from ..types.register_prompt_error_response import RegisterPromptErrorResponse


class ConflictError(ApiError):
    def __init__(self, body: RegisterPromptErrorResponse):
        super().__init__(status_code=409, body=body)
