# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .chat_message_role import ChatMessageRole
from .vellum_variable_type import VellumVariableType

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class PromptTemplateBlockProperties(pydantic.BaseModel):
    chat_role: typing.Optional[ChatMessageRole] = None
    chat_message_unterminated: typing.Optional[bool] = None
    chat_source: typing.Optional[str] = None
    template: typing.Optional[str] = None
    template_type: typing.Optional[VellumVariableType] = None
    function_name: typing.Optional[str] = None
    function_description: typing.Optional[str] = None
    function_parameters: typing.Optional[typing.Dict[str, typing.Any]] = None
    function_forced: typing.Optional[bool] = None
    blocks: typing.Optional[typing.List[PromptTemplateBlock]] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


from .prompt_template_block import PromptTemplateBlock  # noqa: E402

PromptTemplateBlockProperties.update_forward_refs()
